@@ -42,7 +42,7 @@ DEFAULT_SPECD_PATH = os.path.join(
     os.path.dirname(__file__), "../../gosdk/specs/"
 )
 
-VERSION = "0.9.12"
+VERSION = "0.9.13"
 COPYRIGHT = "Copyright: GenomOncology, LLC"
 
 
@@ -414,12 +414,7 @@ def annotate_calls(
 @options.size_option
 @options.build_option
 @options.pass_state
-def annotate_match(
-    state,
-    run_async,
-    delete_if_exists,
-    keep_ref_unknown_calls,
-):
+def annotate_match(state, run_async, delete_if_exists, keep_ref_unknown_calls):
     """Get annotations for stream of calls."""
     if run_async:
         create_function = kms.create_async_processor
