@@ -56,9 +56,7 @@ async def async_annotate_match(
         annotations_list = None
 
     annotated_calls = annotate_match_calls(
-        annotations_list,
-        data,
-        annotation_bundle_version,
+        annotations_list, data, annotation_bundle_version
     )
 
     logger.get_logger().debug(
@@ -95,9 +93,7 @@ def sync_annotate_match(
     )
 
     annotated_calls = annotate_match_calls(
-        annotations_list,
-        data,
-        annotation_bundle_version,
+        annotations_list, data, annotation_bundle_version
     )
 
     logger.get_logger().debug(
@@ -314,22 +310,16 @@ def annotate_hotspots(data):
     return annotations
 
 
-def annotate_match_calls(
-    annotations_list, data, annotation_bundle_version
-):
+def annotate_match_calls(annotations_list, data, annotation_bundle_version):
     func = partial(
-        add_annotation_match,
-        annotations_list,
-        annotation_bundle_version,
+        add_annotation_match, annotations_list, annotation_bundle_version
     )
     annotated_calls = list(map(func, data))
     return annotated_calls
 
 
 def add_annotation_match(
-    annotations_list: AnnotationMatchList,
-    expected_bundle_version,
-    call: dict,
+    annotations_list: AnnotationMatchList, expected_bundle_version, call: dict
 ):  # pragma: no mccabe
 
     if annotations_list and is_call_or_variant(call):
