@@ -4,12 +4,10 @@ VARIANT_TYPE_BLACKLIST = [
     "Phase unknown",
     "Haplotype",
     "fusion",
-    "Inversion",
     "Translocation",
     "Complex",
     "copy number loss",
     "copy number gain",
-    "Microsatellite",
     "CompoundHeterozygote",
     "Diplotype",
 ]
@@ -60,7 +58,7 @@ XREF = "XRef"
 
 
 class ClinvarXMLSource:
-    def __init__(self, file_path):
+    def __init__(self, file_path, **kwargs):
         self.file_path = file_path
 
     def __iter__(self):
@@ -347,6 +345,7 @@ class ClinvarXMLSource:
 
         # build top-level result dict with fields that could be parsed
         record = {}
+        alterations = set()
         if clinsig is not None:
             record["CLNSIG__mstring"] = clinsig
         if variation_id is not None:
@@ -359,6 +358,7 @@ class ClinvarXMLSource:
             record["CLNDN__mstring"] = clndn
         if alteration_string:
             record["alteration__string"] = alteration_string
+            alterations.add(alteration_string)
         if hgvs_g:
             record["hgvs_g"] = hgvs_g
         if chromosome:
@@ -367,6 +367,7 @@ class ClinvarXMLSource:
             record["position"] = position
         if len(genes) > 0:
             record["gene"] = genes
+        record["alterations"] = list(alterations)
         record = self.iterate_individual_submissions(
             clinical_assertions, record, interpreted_record
         )
