@@ -63,7 +63,7 @@ NAME_MAPPING = {
     "1000Gp3_EUR_AF__float": "1000Gp3_EUR_AF",
     "1000Gp3_SAS_AC__int": "1000Gp3_SAS_AC",
     "1000Gp3_SAS_AF__float": "1000Gp3_SAS_AF",
-    "cds_strand__string": "cds_strand",
+    "cds_strand__mstring": "cds_strand",
     "MutationTaster_AAE__mstring": "MutationTaster_AAE",
     "MutationTaster_converted_rankscore__float": "MutationTaster_converted_rankscore",  # noqa E501
     "MutationTaster_model__mstring": "MutationTaster_model",
@@ -76,8 +76,8 @@ NAME_MAPPING = {
     "PROVEAN_converted_rankscore__float": "PROVEAN_converted_rankscore",
     "PROVEAN_pred__mstring": "PROVEAN_pred",
     "PROVEAN_score__mfloat": "PROVEAN_score",
-    "codonpos__int": "codonpos",
-    "codon_degeneracy__string": "codon_degeneracy",
+    "codonpos__mint": "codonpos",
+    "codon_degeneracy__mstring": "codon_degeneracy",
     "Ancestral_allele__string": "Ancestral_allele",
     "AltaiNeandertal__string": "AltaiNeandertal",
     "Denisova__string": "Denisova",
@@ -166,15 +166,44 @@ NAME_MAPPING = {
     "SIFT4G_converted_rankscore__float": "SIFT4G_converted_rankscore",
     "SIFT4G_pred__mstring": "SIFT4G_pred",
     "SIFT4G_score__mfloat": "SIFT4G_score",
+    # CADD
+    "CADD_raw__float": "CADD_raw",
+    "CADD_raw_rankscore__float": "CADD_raw_rankscore",
+    "CADD_phred__float": "CADD_phred",
+    "CADD_raw_hg19__float": "CADD_raw_hg19",
+    "CADD_raw_rankscore_hg19__float": "CADD_raw_rankscore_hg19",
+    "CADD_phred_hg19__float": "CADD_phred_hg19",
 }
 
+
+def add_alteration(ann):
+    alterations = set()
+    genes = ann.get("gene", [])
+    p_dots = ann.get("HGVSp_ANNOVAR__mstring", [])
+    assert len(genes) == len(p_dots), (
+        f"{ann.get('hgvs_g', '')} has {len(genes)} genes "
+        f"and {len(p_dots)} p_dots. These must match."
+    )
+    # clean p_dots --> replace X with * and strip out "p."
+    p_dots = [p_dot.split("p.")[-1].replace("X", "*") for p_dot in p_dots]
+    for i in range(0, len(genes)):
+        alterations.add(f"{genes[i]} {p_dots[i]}")
+    return list(alterations)
+
+
+def clean_genes(ann):
+    return ann.get("gene", "").split(";")
+
+
 register(
     input_type=DocType.TSV,
     output_type=DocType.DBNSFP,
     transformer=compose(
         filter_out_empty_chr_start,
         additional_clean_up,
+        lambda x: assoc(x, "alterations", add_alteration(x)),
         lambda x: assoc(x, "hgvs_g", kms.annotations.to_csra(x)),
+        lambda x: assoc(x, "gene", clean_genes(x)),
         lambda x: assoc(x, __TYPE__, DocType.DBNSFP.value),
         name_mapping(
             NAME_MAPPING, empty_values=(None, "."), split_chars=SPLIT_CHARS
